@@ -60,6 +60,7 @@ impl Cli {
             .error_to_file(std::mem::replace(&mut self.error_to_file,None))?
             .debug(args.is_present("debug"))
             .log(args.is_present("log"))
+            .diff(args.is_present("diff"))?
             .interactive(args.is_present("interactive"))
             .build();
 
@@ -160,26 +161,27 @@ impl Cli {
     /// Creates argument template wich clap macro
     fn args_builder() -> clap::ArgMatches {
         clap_app!(rad =>
-            (version: "0.9.0")
+            (version: "0.9.1")
             (author: "Simon Creek <simoncreek@tutanota.com>")
             (about: "R4d is a modern macro processor made with rust")
             (@arg FILE: ... "Files to execute processing")
-            (@arg out: -o --out +takes_value "File to print out macro")
+            (@arg out: -o --out +takes_value conflicts_with[discard] "File to print out macro")
             (@arg err: -e --err +takes_value "File to save logs")
             (@arg greedy: -g --greedy "Make all macro invocation greedy")
             (@arg melt: ... -m --melt +takes_value "Frozen file to reads")
             (@arg freeze: -f --freeze +takes_value "Freeze to file")
             (@arg purge: -p --purge "Purge unused macros")
-            (@arg nopanic: --nopanic "Allow panic")
-            (@arg strict: -S --strict "Strict mode")
+            (@arg nopanic: --nopanic "Don't panic in any circumstances")
+            (@arg strict: -S --strict conflicts_with[nopanic purge] "Strict mode")
             (@arg debug: -d --debug "Debug mode")
             (@arg log: -l --log "Debug log mode")
+            (@arg diff: --diff "Show diff result")
             (@arg interactive: -i --interactive "Use interactive debug mode")
             (@arg combination: -c "Read from both stdin and file inputs")
             (@arg discard: -D --discard "Discard output without print out")
             (@arg allow: -a +takes_value "Allow permission (fin|fout|cmd|env)")
             (@arg allow_warn: -w +takes_value "Allow permission with warnings (fin|fout|cmd|env)")
-            (@arg allow_all: -A "Allow all permission")
+            (@arg allow_all: -A conflicts_with[allow_all_warn] "Allow all permission")
             (@arg allow_all_warn: -W "Allow all permission with warning")
             (@arg silent: -s "Supress warnings")
             (@arg newline: -n "Use unix newline for formatting")
